@@ -699,12 +699,17 @@ class JunebugApi(object):
                             'name': queue['name'],
                             'stuck': False,
                             'messages': queue.get('messages'),
-                            'rate':
-                                queue['message_stats']['ack_details']['rate']
                         }
-                        if (details['messages'] > 0 and details['rate'] == 0):
-                            stuck = True
-                            details['stuck'] = True
+
+                        # Use the rate from message_stats if it is there
+                        if("message_stats" in queue):
+                            details['rate'] = \
+                                queue['message_stats']['ack_details']['rate']
+
+                            if (details['messages'] > 0
+                                    and details['rate'] == 0):
+                                stuck = True
+                                details['stuck'] = True
 
                         queues.append(details)
 
